@@ -588,12 +588,12 @@ input_testing <- function(input, p_val_threshold = 0.05) {
     stop("the input is not a data frame")
   }
 
-  if (nrow(input) < 2) {
-    stop("There must be at least 2 rows (genes) in the input data frame")
+  if (ncol(input) != 2 & ncol(input) != 3) {
+    stop("the input should have 2 or 3 columns")
   }
 
-  if (ncol(input) < 2) {
-    stop("There must be at least 2 columns in the input data frame")
+  if (nrow(input) < 2) {
+    stop("There must be at least 2 rows (genes) in the input data frame")
   }
 
   if (!is.numeric(p_val_threshold)) {
